<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" sourcelanguage="en" version="2.0">
<context>
    <name>Account</name>
    <message>
        <location filename="../src/account.cpp" line="331"/>
        <source>Ready</source>
        <extracomment>Account state</extracomment>
        <translation>Готов</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="333"/>
        <source>Registered</source>
        <extracomment>Account state</extracomment>
        <translation>Зарегистрирован</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="335"/>
        <source>Not Registered</source>
        <extracomment>Account state</extracomment>
        <translation>Не зарегистрирован</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="337"/>
        <source>Initializing</source>
        <extracomment>Account state</extracomment>
        <translation>Инициализация</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="339"/>
        <source>Trying...</source>
        <extracomment>Account state</extracomment>
        <translation>Попытка...</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="341"/>
        <source>Error</source>
        <extracomment>Account state</extracomment>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="343"/>
        <source>Authentication Failed</source>
        <extracomment>Account state</extracomment>
        <translation>Аутентификация не удалась</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="345"/>
        <source>Network unreachable</source>
        <extracomment>Account state</extracomment>
        <translation>Сеть недоступна</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="347"/>
        <source>Host unreachable</source>
        <extracomment>Account state</extracomment>
        <translation>Узел недоступен</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="349"/>
        <source>Stun configuration error</source>
        <extracomment>Account state</extracomment>
        <translation>Ошибка настройки STUN</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="351"/>
        <source>Stun server invalid</source>
        <extracomment>Account state</extracomment>
        <translation>Неверный сервер STUN</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="353"/>
        <source>Service unavailable</source>
        <extracomment>Account state</extracomment>
        <translation>Служба недоступна</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="355"/>
        <source>Unacceptable</source>
        <extracomment>Account state</extracomment>
        <translation>Недопустимый</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="357"/>
        <source>Invalid</source>
        <extracomment>Account state</extracomment>
        <translation>Неверный</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="359"/>
        <source>Request Timeout</source>
        <extracomment>Account state</extracomment>
        <translation>Время ожидания запроса</translation>
    </message>
</context>
<context>
    <name>AccountChecksModel</name>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="438"/>
        <source>Configuration</source>
        <translation>Настройка</translation>
    </message>
</context>
<context>
    <name>BootstrapModel</name>
    <message>
        <location filename="../src/bootstrapmodel.cpp" line="379"/>
        <source>Hostname</source>
        <translation>Имя хоста</translation>
    </message>
    <message>
        <location filename="../src/bootstrapmodel.cpp" line="381"/>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
</context>
<context>
    <name>Call</name>
    <message>
        <location filename="../src/call.cpp" line="720"/>
        <source>New</source>
        <extracomment>Call state</extracomment>
        <translation>Новый</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="723"/>
        <source>Ringing</source>
        <extracomment>Call state</extracomment>
        <translation>Звонок</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="726"/>
        <source>Calling</source>
        <extracomment>Call state</extracomment>
        <translation>Вызов</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="729"/>
        <source>Talking</source>
        <extracomment>Call state</extracomment>
        <translation>Разговор</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="732"/>
        <source>Dialing</source>
        <extracomment>Call state</extracomment>
        <translation>Набор</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="735"/>
        <source>Hold</source>
        <extracomment>Call state</extracomment>
        <translation>На удержании</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="738"/>
        <source>Failed</source>
        <extracomment>Call state</extracomment>
        <translation>Сбой</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="741"/>
        <source>Busy</source>
        <extracomment>Call state</extracomment>
        <translation>Занято</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="744"/>
        <source>Transfer</source>
        <extracomment>Call state</extracomment>
        <translation>Перевод</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="747"/>
        <source>Transfer hold</source>
        <extracomment>Call state</extracomment>
        <translation>Удержание перевода</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="750"/>
        <source>Over</source>
        <extracomment>Call state</extracomment>
        <translation>Окончен</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="753"/>
        <source>Error</source>
        <extracomment>Call state</extracomment>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="756"/>
        <location filename="../src/call.cpp" line="861"/>
        <source>Conference</source>
        <extracomment>Call state</extracomment>
        <translation>Конференция</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="759"/>
        <source>Conference (hold)</source>
        <extracomment>Call state</extracomment>
        <translation>Конференция (удержание)</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="762"/>
        <source>ERROR</source>
        <extracomment>Call state</extracomment>
        <translation>ОШИБКА</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="765"/>
        <source>Searching for</source>
        <extracomment>Call state</extracomment>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="768"/>
        <source>Aborted</source>
        <extracomment>Call state</extracomment>
        <translation>Прервано</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="771"/>
        <source>Communication established</source>
        <extracomment>Call state</extracomment>
        <translation>Соединение установлено</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="865"/>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="2243"/>
        <source>Account: </source>
        <translation>Аккаунт:</translation>
    </message>
</context>
<context>
    <name>CallModel</name>
    <message>
        <location filename="../src/callmodel.cpp" line="920"/>
        <source>Calls</source>
        <translation>Звонки</translation>
    </message>
</context>
<context>
    <name>CallModelPrivate</name>
    <message>
        <location filename="../src/callmodel.cpp" line="555"/>
        <location filename="../src/callmodel.cpp" line="580"/>
        <source>Invalid account</source>
        <translation>Недопустимый аккаунт</translation>
    </message>
</context>
<context>
    <name>CallPrivate</name>
    <message>
        <location filename="../src/call.cpp" line="1794"/>
        <source>Aborted</source>
        <translation>Прервано</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="1815"/>
        <source>No account registered!</source>
        <translation>Нет зарегистрированных аккаунтов!</translation>
    </message>
</context>
<context>
    <name>CategorizedBookmarkModel</name>
    <message>
        <location filename="../src/categorizedbookmarkmodel.cpp" line="181"/>
        <source>Most popular</source>
        <extracomment>Most popular contacts</extracomment>
        <translation>Наиболее популярные</translation>
    </message>
    <message>
        <location filename="../src/categorizedbookmarkmodel.cpp" line="299"/>
        <source>Contacts</source>
        <translation>Контакты</translation>
    </message>
</context>
<context>
    <name>CategorizedContactModel</name>
    <message>
        <location filename="../src/categorizedcontactmodel.cpp" line="401"/>
        <source>Contacts</source>
        <translation>Контакты</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="129"/>
        <source>Empty</source>
        <translation>Пусто</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="135"/>
        <location filename="../src/private/sortproxies.cpp" line="153"/>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="141"/>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="147"/>
        <source>Other</source>
        <translation>Другие</translation>
    </message>
</context>
<context>
    <name>CategorizedHistoryModel</name>
    <message>
        <location filename="../src/categorizedhistorymodel.cpp" line="414"/>
        <source>History</source>
        <translation>История</translation>
    </message>
</context>
<context>
    <name>ChainOfTrustModel</name>
    <message>
        <location filename="../src/chainoftrustmodel.cpp" line="173"/>
        <source>Chain of trust</source>
        <translation>Цепочка доверия</translation>
    </message>
</context>
<context>
    <name>CollectionModel</name>
    <message>
        <location filename="../src/collectionmodel.cpp" line="279"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
</context>
<context>
    <name>ContactSortingCategoryModel</name>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="49"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="50"/>
        <source>Organisation</source>
        <translation>Организация</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="51"/>
        <source>Recently used</source>
        <translation>Недавно использованный</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="52"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="53"/>
        <source>Department</source>
        <translation>Отдел</translation>
    </message>
</context>
<context>
    <name>HistorySortingCategoryModel</name>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="57"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="58"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="59"/>
        <source>Popularity</source>
        <translation>Популярность</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="60"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="61"/>
        <source>Total time</source>
        <translation>Общее время</translation>
    </message>
</context>
<context>
    <name>HistoryTimeCategoryModel</name>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="40"/>
        <source>Today</source>
        <translation>Сегодня</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="41"/>
        <source>Yesterday</source>
        <translation>Вчера</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="48"/>
        <source>Two weeks ago</source>
        <translation>Две недели назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="49"/>
        <source>Three weeks ago</source>
        <translation>Три недели назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="47"/>
        <source>A week ago</source>
        <translation>Неделю назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="50"/>
        <source>A month ago</source>
        <translation>Месяц назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="51"/>
        <source>Two months ago</source>
        <translation>Два месяца назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="52"/>
        <source>Three months ago</source>
        <translation>Три месяца назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="53"/>
        <source>Four months ago</source>
        <translation>Четыре месяца назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="54"/>
        <source>Five months ago</source>
        <translation>Пять месяцев назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="55"/>
        <source>Six months ago</source>
        <translation>Шесть месяцев назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="56"/>
        <source>Seven months ago</source>
        <translation>Семь месяцев назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="57"/>
        <source>Eight months ago</source>
        <translation>Восемь месяцев назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="58"/>
        <source>Nine months ago</source>
        <translation>Девять месяцев назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="59"/>
        <source>Ten months ago</source>
        <translation>Десять месяцев назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="60"/>
        <source>Eleven months ago</source>
        <translation>Одиннадцать месяцев назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="61"/>
        <source>Twelve months ago</source>
        <translation>Двенадцать месяцев назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="62"/>
        <source>A year ago</source>
        <translation>Год назад</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="63"/>
        <source>Very long time ago</source>
        <translation>Очень давно</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="64"/>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
</context>
<context>
    <name>InstantMessagingModel</name>
    <message>
        <location filename="../src/media/textrecording.cpp" line="816"/>
        <source>Me</source>
        <translation>Я</translation>
    </message>
</context>
<context>
    <name>MacroModel</name>
    <message>
        <location filename="../src/macromodel.cpp" line="157"/>
        <source>Macros</source>
        <translation>Макрос</translation>
    </message>
    <message>
        <location filename="../src/macromodel.cpp" line="263"/>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <location filename="../src/macromodel.cpp" line="264"/>
        <source>Other</source>
        <translation>Другой</translation>
    </message>
</context>
<context>
    <name>MacroModelPrivate</name>
    <message>
        <location filename="../src/macromodel.cpp" line="77"/>
        <source>Other</source>
        <translation>Другой</translation>
    </message>
</context>
<context>
    <name>Media::RecordingModel</name>
    <message>
        <location filename="../src/media/recordingmodel.cpp" line="189"/>
        <source>Recordings</source>
        <translation>Записи</translation>
    </message>
    <message>
        <location filename="../src/media/recordingmodel.cpp" line="259"/>
        <source>Text messages</source>
        <translation>Текстовые сообщения</translation>
    </message>
    <message>
        <location filename="../src/media/recordingmodel.cpp" line="264"/>
        <source>Audio/Video</source>
        <translation>Аудио/Видео</translation>
    </message>
</context>
<context>
    <name>NumberCategoryModel</name>
    <message>
        <location filename="../src/numbercategorymodel.cpp" line="56"/>
        <source>Uncategorized</source>
        <translation>Без категории</translation>
    </message>
</context>
<context>
    <name>NumberCompletionModel</name>
    <message>
        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
        <source>Account</source>
        <translation>Аккаунт</translation>
    </message>
    <message>
        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
        <source>Weight</source>
        <translation>Вес</translation>
    </message>
</context>
<context>
    <name>PersonModel</name>
    <message>
        <location filename="../src/personmodel.cpp" line="171"/>
        <source>Persons</source>
        <translation>Люди</translation>
    </message>
</context>
<context>
    <name>PhoneDirectoryModel</name>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="234"/>
        <source>This account does not support presence tracking</source>
        <translation>Этот аккаунт не поддерживает отслеживание присутствия</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="237"/>
        <source>No associated account</source>
        <translation>Нет связанных аккаунтов</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Person</source>
        <translation>Человек</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Account</source>
        <translation>Аккаунт</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>State</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Call count</source>
        <translation>Количество звонков</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Week count</source>
        <translation>Недельный счетчик</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Trimester count</source>
        <translation>Триместровый счетчик</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Have Called</source>
        <translation>Звонили</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Last used</source>
        <translation>Последнее использование</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Name_count</source>
        <translation>Счетчик имен</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Total (in seconds)</source>
        <translation>Всего (сек)</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Popularity_index</source>
        <translation>Индекс популярности</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Bookmarked</source>
        <translation>В закладках</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Tracked</source>
        <translation>Отслеживаются</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Present</source>
        <translation>Текущий</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Presence message</source>
        <translation>Сообщение о присутствии</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Uid</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Has certificate</source>
        <translation>Имеет сертификат</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Registered name</source>
        <translation>Зарегистрированное имя</translation>
    </message>
</context>
<context>
    <name>PresenceStatusModel</name>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Present</source>
        <translation>Текущий</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="308"/>
        <location filename="../src/presencestatusmodel.cpp" line="361"/>
        <source>Custom</source>
        <translation>Настраиваемый</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="308"/>
        <location filename="../src/presencestatusmodel.cpp" line="310"/>
        <location filename="../src/presencestatusmodel.cpp" line="354"/>
        <location filename="../src/presencestatusmodel.cpp" line="361"/>
        <source>N/A</source>
        <translation>Недоступно</translation>
    </message>
</context>
<context>
    <name>ProfileModel</name>
    <message>
        <location filename="../src/profilemodel.cpp" line="637"/>
        <source>Profiles</source>
        <translation>Профили</translation>
    </message>
</context>
<context>
    <name>ProfileModelPrivate</name>
    <message>
        <location filename="../src/profilemodel.cpp" line="751"/>
        <source>New profile</source>
        <translation>Новый профиль</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/accountstatusmodel.cpp" line="177"/>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <location filename="../src/accountstatusmodel.cpp" line="179"/>
        <source>Code</source>
        <translation>Код</translation>
    </message>
    <message>
        <location filename="../src/accountstatusmodel.cpp" line="181"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../src/accountstatusmodel.cpp" line="183"/>
        <source>Counter</source>
        <translation>Счетчик</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="42"/>
        <source>Has a private key</source>
        <translation>Имеет закрытый ключ</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="43"/>
        <source>Is not expired</source>
        <translation>Срок действия не истек</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="44"/>
        <source>Has strong signing</source>
        <translation>Имеет точную подпись</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="45"/>
        <source>Is not self signed</source>
        <translation>Не самоподписан</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="46"/>
        <source>Have a matching key pair</source>
        <translation>Имеет совпадающую пару ключей</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="47"/>
        <source>Has the right private key file permissions</source>
        <translation>Имеет правильные разрешения на файл закрытого ключа</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="48"/>
        <source>Has the right public key file permissions</source>
        <translation>Имеет правильные разрешения на файл открытого ключа</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="49"/>
        <source>Has the right private key directory permissions</source>
        <translation>Имеет правильные разрешения на папку закрытого ключа</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="50"/>
        <source>Has the right public key directory permissions</source>
        <translation>Имеет правильные разрешения на папку открытого ключа</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="51"/>
        <source>Has the right private key directory location</source>
        <translation>Папка закрытого ключа в правильном месте</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="52"/>
        <source>Has the right public key directory location</source>
        <translation>Папка открытого ключа в правильном месте</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="53"/>
        <source>Has the right private key SELinux attributes</source>
        <translation>SELinux атрибуты для закрытого ключа правильны</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="54"/>
        <source>Has the right public key SELinux attributes</source>
        <translation>SELinux атрибуты для открытого ключа правильны</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="55"/>
        <source>The certificate file exist and is readable</source>
        <translation>Файл сертификата существует и доступен для чтения</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="56"/>
        <source>The file is a valid certificate</source>
        <translation>Файл является действительным сертификатом</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="57"/>
        <source>The certificate has a valid authority</source>
        <translation>Сертификат подтверждён удостоверяющим центром</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="58"/>
        <source>The certificate has a known authority</source>
        <translation>Сертификат подтверждён известным удостоверяющим центром</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="59"/>
        <source>The certificate is not revoked</source>
        <translation>Сертификат не отозван</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="60"/>
        <source>The certificate authority match</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="61"/>
        <source>The certificate has the expected owner</source>
        <translation>Сертификат имеет правильного владельца</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="62"/>
        <source>The certificate is within its active period</source>
        <translation>Сертификат активен</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="90"/>
        <source>Expiration date</source>
        <translation>Дата окончания</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="91"/>
        <source>Activation date</source>
        <translation>Дата активации</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="92"/>
        <source>Require a private key password</source>
        <translation>Требуется пароль закрытого ключа</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="93"/>
        <source>Public signature</source>
        <translation>Публичная подпись</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="94"/>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="95"/>
        <source>Serial number</source>
        <translation>Серийный номер</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="96"/>
        <source>Issuer</source>
        <translation>Издатель</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="97"/>
        <source>Subject key algorithm</source>
        <translation>Алгоритм ключа субъекта</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="98"/>
        <source>Common name (CN)</source>
        <translation>Общее название (CN)</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="99"/>
        <source>Name (N)</source>
        <translation>Имя (N)</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="100"/>
        <source>Organization (O)</source>
        <translation>Организация (O)</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="101"/>
        <source>Signature algorithm</source>
        <translation>Алгоритм подписи</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="102"/>
        <source>Md5 fingerprint</source>
        <translation>MD5 отпечаток</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="103"/>
        <source>Sha1 fingerprint</source>
        <translation>SHA-1 отпечаток</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="104"/>
        <source>Public key id</source>
        <translation>ID открытого ключа</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="105"/>
        <source>Issuer domain name</source>
        <translation>Доменное имя издателя</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="106"/>
        <source>Next expected update</source>
        <translation>Следующее ожидаемое обновление</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="107"/>
        <source>Outgoing server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="183"/>
        <source>Local certificate store</source>
        <translation>Локальное хранилище сертификатов</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="267"/>
        <location filename="../src/localprofilecollection.cpp" line="220"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="267"/>
        <source>Certificate not associated with a group</source>
        <translation>Сертификат, не связанный с группой</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="397"/>
        <source>A certificate</source>
        <translation>Сертификат</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="397"/>
        <source>An organisation</source>
        <translation>Организация</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="420"/>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="420"/>
        <source>The content of the certificate</source>
        <translation>Содержимое сертификата</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="421"/>
        <source>Checks</source>
        <translation>Проверки</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="421"/>
        <source>Various security related information</source>
        <translation>Различная информация, связанная с безопасностью</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="610"/>
        <source>Header</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../src/daemoncertificatecollection.cpp" line="148"/>
        <source>Daemon certificate store</source>
        <translation>Служба хранения сертификатов</translation>
    </message>
    <message>
        <location filename="../src/daemoncertificatecollection.cpp" line="152"/>
        <source>%1 banned list</source>
        <extracomment>The list of banned certificates for this account</extracomment>
        <translation>%1 список запрещенных</translation>
    </message>
    <message>
        <location filename="../src/daemoncertificatecollection.cpp" line="155"/>
        <source>%1 allowed list</source>
        <extracomment>The list of allowed certificates for this account</extracomment>
        <translation>%1 список разрешенных</translation>
    </message>
    <message>
        <location filename="../src/daemoncertificatecollection.cpp" line="160"/>
        <location filename="../src/foldercertificatecollection.cpp" line="198"/>
        <source>Certificate</source>
        <translation>Сертификат</translation>
    </message>
    <message>
        <location filename="../src/extensions/presencecollectionextension.cpp" line="38"/>
        <source>Presence tracking</source>
        <translation>Отслеживание присутствия</translation>
    </message>
    <message>
        <location filename="../src/extensions/securityevaluationextension.cpp" line="63"/>
        <source>Security evaluation</source>
        <translation>Оценка безопасности</translation>
    </message>
    <message>
        <location filename="../src/fallbackpersoncollection.cpp" line="194"/>
        <location filename="../src/transitionalpersonbackend.cpp" line="150"/>
        <source>Contact</source>
        <translation>Контакт</translation>
    </message>
    <message>
        <location filename="../src/localbookmarkcollection.cpp" line="212"/>
        <source>Local bookmarks</source>
        <translation>Локальные закладки</translation>
    </message>
    <message>
        <location filename="../src/localbookmarkcollection.cpp" line="217"/>
        <location filename="../src/useractionmodel.cpp" line="532"/>
        <source>Bookmark</source>
        <translation>Закладка</translation>
    </message>
    <message>
        <location filename="../src/localhistorycollection.cpp" line="195"/>
        <source>Local history</source>
        <translation>Локальная история</translation>
    </message>
    <message>
        <location filename="../src/localhistorycollection.cpp" line="200"/>
        <source>History</source>
        <translation>История</translation>
    </message>
    <message>
        <location filename="../src/localmacrocollection.cpp" line="190"/>
        <source>Local macros</source>
        <translation>Локальные макросы</translation>
    </message>
    <message>
        <location filename="../src/localmacrocollection.cpp" line="195"/>
        <source>Macro</source>
        <translation>Макро</translation>
    </message>
    <message>
        <location filename="../src/localrecordingcollection.cpp" line="101"/>
        <source>Local recordings</source>
        <translation>Локальные записи</translation>
    </message>
    <message>
        <location filename="../src/localrecordingcollection.cpp" line="106"/>
        <location filename="../src/localtextrecordingcollection.cpp" line="170"/>
        <source>Recording</source>
        <translation>Запись</translation>
    </message>
    <message>
        <location filename="../src/localringtonecollection.cpp" line="220"/>
        <source>Local ringtones</source>
        <translation>Локальные мелодии звонков</translation>
    </message>
    <message>
        <location filename="../src/localringtonecollection.cpp" line="225"/>
        <source>Ringtone</source>
        <translation>Мелодия звонка</translation>
    </message>
    <message>
        <location filename="../src/localtextrecordingcollection.cpp" line="165"/>
        <source>Local text recordings</source>
        <translation>Локальные текстовые записи</translation>
    </message>
    <message>
        <location filename="../src/numbercategory.cpp" line="72"/>
        <source>Phone number types</source>
        <translation>Типы телефонных номеров</translation>
    </message>
    <message>
        <location filename="../src/numbercategorymodel.cpp" line="186"/>
        <source>Other</source>
        <translation>Другие</translation>
    </message>
    <message>
        <location filename="../src/protocolmodel.cpp" line="50"/>
        <source>Ring Account</source>
        <translation>Аккаунт Ring</translation>
    </message>
    <message>
        <location filename="../src/protocolmodel.cpp" line="51"/>
        <source>SIP Account</source>
        <translation>Аккаунт SIP</translation>
    </message>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>Я</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="38"/>
        <source>TLS is disabled, the negotiation won&apos;t be encrypted. Your communication will be vulnerable to snooping</source>
        <translation>TLS выключен, ваши переговоры не шифруются. Ваше общение может быть прослушано.</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="40"/>
        <source>Your certificate and authority don&apos;t match, if your certificate require an authority, it won&apos;t work</source>
        <translation>Ваш сертификат не соответствует удостоверяющему центру. Если ваш сертификат должен быть подтверждён, он не будет работать.</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="41"/>
        <source>The outgoing server specified doesn&apos;t match the hostname or the one included in the certificate</source>
        <translation>Указанный исходящий сервер не совпадает с именем хоста или с именем, указанным в сертификате</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="42"/>
        <source>The &quot;verify incoming certificate&quot; option is disabled, this leave you vulnerable to man in the middle attack</source>
        <translation>Опция &quot;проверять получаемый сертификат&quot; отключена, это делает вас уязвимым для атаки через посредника</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="43"/>
        <source>The &quot;verify answer certificate&quot; option is disabled, this leave you vulnerable to man in the middle attack</source>
        <translation>Опция &quot;проверять ответный сертификат&quot; отключена, это делает вас уязвимым для атаки через посредника</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="44"/>
        <source>None of your certificate provide a private key, this is required. Please select a private key or use a certificate with one built-in</source>
        <translation>Ни один из ваших сертификатов не содержит закрытый ключ, а это необходимо. Пожалуйста, выберите закрытый ключ или сертификат, в который он встроен.</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="47"/>
        <source>No certificate authority is provided, it won&apos;t be possible to validate if the answer certificates are valid. Some account may also not work.</source>
        <translation>Не указан центр сертификации, поэтому будет невозможно проверить действительность ответных сертификатов. Некоторые аккаунты также могут не работать.</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="46"/>
        <source>No certificate has been provided. This is, for now, unsupported by Ring</source>
        <translation>Сертификат не был предоставлен. В данный момент это не поддерживается Ring.</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="37"/>
        <source>Your media streams are not encrypted, please enable SDES</source>
        <translation>Ваши медиапотоки не зашифрованы, пожалуйста, включите SDES</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="50"/>
        <source>Your certificate is expired, please contact your system administrator.</source>
        <translation>Ваш сертификат истек, пожалуйста, свяжитесь с вашим системным администратором.</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="51"/>
        <source>Your certificate is self signed. This break the chain of trust.</source>
        <translation>Ваш сертификат — самоподписанный. Это разрывает цепочку доверия.</translation>
    </message>
    <message>
        <location filename="../src/tlsmethodmodel.cpp" line="64"/>
        <source>Default</source>
        <comment>Default TLS protocol version</comment>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../src/transitionalpersonbackend.cpp" line="145"/>
        <source>Contact placeholders</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="517"/>
        <location filename="../src/useractionmodel.cpp" line="759"/>
        <source>Accept</source>
        <translation>Принять</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="61"/>
        <location filename="../src/api/call.h" line="77"/>
        <location filename="../src/useractionmodel.cpp" line="518"/>
        <location filename="../src/useractionmodel.cpp" line="771"/>
        <source>Hold</source>
        <translation>Удержать</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="63"/>
        <source>Talking</source>
        <translation>Разговор</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="65"/>
        <source>ERROR</source>
        <translation>ОШИБКА</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="67"/>
        <source>Outgoing requested</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="69"/>
        <source>Incoming</source>
        <translation>Входящий</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="71"/>
        <source>Calling</source>
        <translation>Вызов</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="73"/>
        <source>Connecting</source>
        <translation>Подключение</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="75"/>
        <source>Searching</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="79"/>
        <source>Inactive</source>
        <translation>Неактивен</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="81"/>
        <location filename="../src/api/call.h" line="83"/>
        <source>Finished</source>
        <translation>Завершён</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="85"/>
        <source>Communication established</source>
        <translation>Соединение установлено</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="87"/>
        <source>Auto answering</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="519"/>
        <source>Mute audio</source>
        <translation>Отключить звук</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="520"/>
        <source>Mute video</source>
        <translation>Отключить видео</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="521"/>
        <source>Server transfer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="522"/>
        <source>Record</source>
        <translation>Запись</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="523"/>
        <location filename="../src/useractionmodel.cpp" line="789"/>
        <source>Hangup</source>
        <translation>Повесить трубку</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="524"/>
        <source>Join</source>
        <translation>Присоединиться</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="525"/>
        <source>Add new</source>
        <translation>Добавить новый</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="526"/>
        <source>Toggle video</source>
        <translation>Переключить видео</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="527"/>
        <source>Add a contact</source>
        <translation>Добавить контакт</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="528"/>
        <source>Add to existing contact</source>
        <translation>Добавить в существующий контакт</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="529"/>
        <source>Delete contact</source>
        <translation>Удалить контакт</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="530"/>
        <source>Email contact</source>
        <translation>Отправить email контакту</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="531"/>
        <source>Copy contact</source>
        <translation>Копировать контакт</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="534"/>
        <source>Add phone number</source>
        <translation>Добавить номер телефона</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="535"/>
        <source>Call again</source>
        <translation>Перезвонить</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="536"/>
        <source>Edit contact details</source>
        <translation>Редактировать контактную информацию</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="537"/>
        <source>Remove from history</source>
        <translation>Удалить из истории</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="786"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="756"/>
        <source>Call</source>
        <translation>Звонок</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="533"/>
        <source>Open chat</source>
        <translation>Открыть чат</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="768"/>
        <source>Unhold</source>
        <translation>Снять с удержания</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="779"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/localprofilecollection.cpp" line="147"/>
        <source>Local profiles</source>
        <translation>Локальные профили</translation>
    </message>
    <message>
        <location filename="../src/localprofilecollection.cpp" line="152"/>
        <source>Profile Collection</source>
        <translation>Коллекция профилей</translation>
    </message>
    <message>
        <location filename="../src/peerprofilecollection.cpp" line="141"/>
        <source>Peer profiles</source>
        <translation>Профили участников</translation>
    </message>
    <message>
        <location filename="../src/peerprofilecollection.cpp" line="146"/>
        <source>Peers Profiles Collection</source>
        <translation>Коллекция профилей участников</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1231"/>
        <location filename="../src/conversationmodel.cpp" line="1596"/>
        <location filename="../src/conversationmodel.cpp" line="1846"/>
        <source>Invitation received</source>
        <translation>Получено приглашение</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1232"/>
        <source>Contact added</source>
        <translation>Контакт добавлен</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1267"/>
        <location filename="../src/conversationmodel.cpp" line="1274"/>
        <source>Invitation accepted</source>
        <translation>Приглашение принято</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1478"/>
        <source>ð Outgoing call</source>
        <translation>ð Исходящий вызов</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1480"/>
        <source>ð Incoming call</source>
        <translation>ð Входящий вызов</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1493"/>
        <source>ð Outgoing call - </source>
        <translation>ð Исходящий вызов - </translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1496"/>
        <source>ð Incoming call - </source>
        <translation>ð Входящий вызов - </translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1500"/>
        <source>ð½ Missed outgoing call</source>
        <translation>ð½ Непринятый исходящий вызов</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1502"/>
        <source>ð½ Missed incoming call</source>
        <translation>ð½ Пропущенный входящий вызов</translation>
    </message>
</context>
<context>
    <name>RecentModel</name>
    <message>
        <location filename="../src/recentmodel.cpp" line="614"/>
        <source>Recent persons</source>
        <translation>Недавние люди</translation>
    </message>
</context>
<context>
    <name>RingDeviceModel</name>
    <message>
        <location filename="../src/ringdevicemodel.cpp" line="110"/>
        <source>Id</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../src/ringdevicemodel.cpp" line="112"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
</context>
<context>
    <name>SecurityEvaluationModelPrivate</name>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="683"/>
        <source>Authority</source>
        <translation>Надежный источник</translation>
    </message>
</context>
<context>
    <name>TlsMethodModel</name>
    <message>
        <location filename="../src/tlsmethodmodel.cpp" line="101"/>
        <source>Automatic</source>
        <translation>Автоматическая</translation>
    </message>
</context>
<context>
    <name>Video::SourceModel</name>
    <message>
        <location filename="../src/video/sourcemodel.cpp" line="95"/>
        <source>NONE</source>
        <translation>НЕТ</translation>
    </message>
    <message>
        <location filename="../src/video/sourcemodel.cpp" line="101"/>
        <source>SCREEN</source>
        <translation>ЭКРАН</translation>
    </message>
    <message>
        <location filename="../src/video/sourcemodel.cpp" line="107"/>
        <source>FILE</source>
        <translation>ФАЙЛ</translation>
    </message>
</context>
</TS>